@@ -1,29 +1,31 @@
 //! This module corresponds to `mach/mach_traps.h`.
+use crate::kern_return::kern_return_t;
+use crate::port::{mach_port_name_t, mach_port_t};
+use core::ffi::c_int;
 
-use kern_return::kern_return_t;
-use port::{mach_port_name_t, mach_port_t};
-
-extern "C" {
+unsafe extern "C" {
     static mach_task_self_: mach_port_t;
     pub fn task_for_pid(
         target_tport: mach_port_name_t,
-        pid: ::libc::c_int,
+        pid: c_int,
         tn: *mut mach_port_name_t,
     ) -> kern_return_t;
 }
 
+#[allow(clippy::missing_safety_doc)] // FIXME
 pub unsafe fn mach_task_self() -> mach_port_t {
-    mach_task_self_
+    unsafe { mach_task_self_ }
 }
 
+#[allow(clippy::missing_safety_doc)] // FIXME
 pub unsafe fn current_task() -> mach_port_t {
-    mach_task_self()
+    unsafe { mach_task_self() }
 }
 
 #[cfg(test)]
 mod tests {
-    use port::*;
-    use traps::*;
+    use crate::port::*;
+    use crate::traps::*;
 
     #[test]
     fn mach_task_self_sanity() {
